@@ -8,11 +8,11 @@ from .base import BaseParser
 try:
     import urlparse
 except ImportError:
-    import urllib.parse as urlparse
+    from urllib import parse as urlparse
 
 
 class CnmlParser(BaseParser):
-    """ CNML 0.1 parser """
+    """CNML 0.1 parser"""
 
     protocol = 'static'
     version = None
